@@ -11,17 +11,17 @@ describe "A" do
 
   describe "subclass gets randomly executed first" do
     it "is called when used" do
-      calls.must_equal []
-      foo.must_equal nil
-      calls.must_equal [1]
+      _(calls).must_equal []
+      _(foo).must_be_nil
+      _(calls).must_equal [1]
     end
   end
 
   describe "then another subclass" do
     it "is not called multiple times" do
-      calls.must_equal []
-      foo.must_equal nil
-      calls.must_equal []
+      _(calls).must_equal []
+      _(foo).must_be_nil
+      _(calls).must_equal []
     end
   end
 
@@ -29,17 +29,17 @@ describe "A" do
     let_all(:foo) { calls << 2; true }
 
     it "can overwrite" do
-      calls.must_equal []
-      foo.must_equal true
-      calls.must_equal [2]
+      _(calls).must_equal []
+      _(foo).must_equal true
+      _(calls).must_equal [2]
     end
   end
 
   describe "nested" do
     it "is not called multiple times from child classes" do
-      calls.must_equal []
-      foo.must_equal nil
-      calls.must_equal []
+      _(calls).must_equal []
+      _(foo).must_be_nil
+      _(calls).must_equal []
     end
   end
 end
@@ -48,7 +48,7 @@ describe "B" do
   let_all(:foo) { :foo }
 
   it "does not go across class boundaries" do
-    foo.must_equal :foo
+    _(foo).must_equal :foo
   end
 end
 
