@@ -2,6 +2,6 @@ require "./spec/cases/helper"
 
 describe 1 do
   it "is even" do
-    2.even?.must_equal true
+    _(2.even?).must_equal true
   end
 end
